@@ -235,6 +235,9 @@ def do_image_create_via_import(gc, args):
         # determine if backend is valid
         _validate_backend(backend, gc)
     elif stores:
+        # NOTE(jokke): Making sure here that we do not include the stores in
+        # the create call
+        fields.pop("stores")
         stores = str(stores).split(',')
         for store in stores:
             # determine if backend is valid
@@ -465,16 +468,42 @@ def do_image_show(gc, args):
     utils.print_image(image, args.human_readable, int(args.max_column_width))
 
 
+@utils.arg('id', metavar='<IMAGE_ID>', help=_('ID of image to get tasks.'))
+def do_image_tasks(gc, args):
+    """Get tasks associated with image"""
+    columns = ['Message', 'Status', 'Updated at']
+    if args.verbose:
+        columns_to_prepend = ['Image Id', 'Task Id']
+        columns_to_extend = ['User Id', 'Request Id',
+                             'Result', 'Owner', 'Input', 'Expires at']
+        columns = columns_to_prepend + columns + columns_to_extend
+    try:
+        tasks = gc.images.get_associated_image_tasks(args.id)
+        utils.print_dict_list(tasks['tasks'], columns)
+    except exc.HTTPNotFound:
+        utils.exit('Image %s not found.' % args.id)
+    except exc.HTTPNotImplemented:
+        utils.exit('Server does not support image tasks API (v2.12)')
+
+
 @utils.arg('--image-id', metavar='<IMAGE_ID>', required=True,
            help=_('Image to display members of.'))
 def do_member_list(gc, args):
     """Describe sharing permissions by image."""
-
     members = gc.image_members.list(args.image_id)
     columns = ['Image ID', 'Member ID', 'Status']
     utils.print_list(members, columns)
 
 
+@utils.arg('image_id', metavar='<IMAGE_ID>',
+           help=_('Image from which to display member.'))
+@utils.arg('member_id', metavar='<MEMBER_ID>',
+           help=_('Project to display.'))
+def do_member_get(gc, args):
+    """Show details of an image member"""
+    member = gc.image_members.get(args.image_id, args.member_id)
+    utils.print_dict(member)
+
 @utils.arg('image_id', metavar='<IMAGE_ID>',
            help=_('Image from which to remove member.'))
 @utils.arg('member_id', metavar='<MEMBER_ID>',
